==> mauticGIT-Test-20251111_133203.tar.gz: var/www/html/mauticGIT-Test/var/tmp/twig/ff/ff6ff8ea8b62dfb2a48dfbf8973275c0.php <==
<?php

use Twig\Environment;
use Twig\Error\LoaderError;
use Twig\Error\RuntimeError;
use Twig\Extension\CoreExtension;
use Twig\Extension\SandboxExtension;
use Twig\Markup;
use Twig\Sandbox\SecurityError;
use Twig\Sandbox\SecurityNotAllowedTagError;
use Twig\Sandbox\SecurityNotAllowedFilterError;
use Twig\Sandbox\SecurityNotAllowedFunctionError;
use Twig\Source;
use Twig\Template;
use Twig\TemplateWrapper;

/* @bundles/IntegrationsBundle/Sync/Notification/Helper/UserSummaryNotificationHelper.php */
class __TwigTemplate_894e6bc9185fd7c32da6801acc0b9777 extends Template
{
    private Source $source;
    /**
     * @var array<string, Template>
     */
    private array $macros = [];

    public function __construct(Environment $env)
    {
        parent::__construct($env);

        $this->source = $this->getSourceContext();

        $this->parent = false;

        $this->blocks = [
        ];
    }

    protected function doDisplay(array $context, array $blocks = []): iterable
    {
        $macros = $this->macros;
        // line 1
        yield "<?php

declare(strict_types=1);

namespace Mautic\\IntegrationsBundle\\Sync\\Notification\\Helper;

use Mautic\\IntegrationsBundle\\Sync\\Exception\\ObjectNotSupportedException;
use Mautic\\IntegrationsBundle\\Sync\\Notification\\Writer;
use Symfony\\Contracts\\Translation\\TranslatorInterface;

class UserSummaryNotificationHelper
{
    /**
     * @var array
     */
    private \$userNotifications = [];

    /**
     * @var string
     */
    private \$integrationDisplayName;

    /**
     * @var string
     */
    private \$objectDisplayName;

    private ?string \$mauticObject = null;

    private ?string \$listTranslationKey = null;

    public function __construct(
        private Writer \$writer,
        private UserHelper \$userHelper,
        private OwnerProvider \$ownerProvider,
        private RouteHelper \$routeHelper,
        private TranslatorInterface \$translator
    ) {
    }

    /**
     * @throws ObjectNotSupportedException
     * @throws \\Doctrine\\ORM\\ORMException
     */
    public function writeNotifications(string \$mauticObject, string \$listTranslationKey): void
    {
        \$this->mauticObject       = \$mauticObject;
        \$this->listTranslationKey = \$listTranslationKey;

        if (empty(\$this->userNotifications)) {
            return;
        }

        foreach (\$this->userNotifications as \$integrationDisplayName => \$integrationNotifications) {
            foreach (\$integrationNotifications as \$objectDisplayName => \$objectNotifications) {
                \$this->integrationDisplayName = \$integrationDisplayName;
                \$this->objectDisplayName      = \$objectDisplayName;

                \$this->findAndSendToUsers(\$objectNotifications);
            }
        }

        \$this->userNotifications = [];
    }

    public function storeSummaryNotification(string \$integrationDisplayName, string \$objectDisplayName, int \$id): void
    {
        if (!isset(\$this->userNotifications[\$integrationDisplayName])) {
            \$this->userNotifications[\$integrationDisplayName] = [];
        }

        if (!isset(\$this->userNotifications[\$integrationDisplayName][\$objectDisplayName])) {
            \$this->userNotifications[\$integrationDisplayName][\$objectDisplayName] = [];
        }

        \$this->userNotifications[\$integrationDisplayName][\$objectDisplayName][\$id] = \$id;
    }

    /**
     * @throws \\Doctrine\\ORM\\ORMException
     * @throws ObjectNotSupportedException
     */
    private function findAndSendToUsers(array \$ids): void
    {
        \$results = \$this->ownerProvider->getOwnersForObjectIds(\$this->mauticObject, \$ids);
        \$owners  = [];

        // Group by owner ID.
        foreach (\$results as \$result) {
            \$ownerId = \$result['owner_id'];
            if (!isset(\$owners[\$ownerId])) {
                \$owners[\$ownerId] = [];
            }

            \$owners[\$ownerId][] = (int) \$result['id'];
        }

        foreach (\$owners as \$userId => \$ownedObjectIds) {
            // Keep track of who is left over to send to admins instead
            \$ids = array_diff(\$ids, \$ownedObjectIds);

            \$this->writeNotification(\$ownedObjectIds, \$userId);
        }

        if (count(\$ids)) {
            // Send the rest to admins
            \$adminUserIds = \$this->userHelper->getAdminUsers();
            foreach (\$adminUserIds as \$userId) {
                \$this->writeNotification(\$ids, \$userId);
            }
        }
    }

    /**
     * @throws ObjectNotSupportedException
     * @throws \\Doctrine\\ORM\\ORMException
     */
    private function writeNotification(array \$ids, int \$userId): void
    {
        \$count = count(\$ids);

        if (\$count > 25) {
            \$this->writer->writeUserNotification(
                \$this->translator->trans(
                    'mautic.integration.sync.user_notification.header',
                    [
                        '%integration%' => \$this->integrationDisplayName,
                        '%object%'      => ucfirst(\$this->objectDisplayName),
                    ]
                ),
                \$this->translator->trans(
                    'mautic.integration.sync.user_notification.count_message',
                    ['%count%' => \$count]
                ),
                \$userId
            );

            return;
        }

        \$this->writer->writeUserNotification(
            \$this->translator->trans(
                'mautic.integration.sync.user_notification.header',
                [
                    '%integration%' => \$this->integrationDisplayName,
                    '%object%'      => ucfirst(\$this->objectDisplayName),
                ]
            ),
            \$this->translator->trans(
                \$this->listTranslationKey,
                [
                    '%contacts%' => \$this->routeHelper->getLinkCsv(\$this->mauticObject, \$ids),
                ]
            ),
            \$userId
        );
    }
}
";
        yield from [];
    }

    /**
     * @codeCoverageIgnore
     */
    public function getTemplateName(): string
    {
        return "@bundles/IntegrationsBundle/Sync/Notification/Helper/UserSummaryNotificationHelper.php";
    }

    /**
     * @codeCoverageIgnore
     */
    public function getDebugInfo(): array
    {
        return array (  42 => 1,);
    }

    public function getSourceContext(): Source
    {
        return new Source("", "@bundles/IntegrationsBundle/Sync/Notification/Helper/UserSummaryNotificationHelper.php", "/var/www/mautic-ktn/app/bundles/IntegrationsBundle/Sync/Notification/Helper/UserSummaryNotificationHelper.php");
    }
}

==> mauticGIT-Test-20260116_092227.tar.gz: var/www/html/mauticGIT-Test/var/tmp/twig/ff/ff6ff8ea8b62dfb2a48dfbf8973275c0.php <==
<?php

use Twig\Environment;
use Twig\Error\LoaderError;
use Twig\Error\RuntimeError;
use Twig\Extension\CoreExtension;
use Twig\Extension\SandboxExtension;
use Twig\Markup;
use Twig\Sandbox\SecurityError;
use Twig\Sandbox\SecurityNotAllowedTagError;
use Twig\Sandbox\SecurityNotAllowedFilterError;
use Twig\Sandbox\SecurityNotAllowedFunctionError;
use Twig\Source;
use Twig\Template;
use Twig\TemplateWrapper;

/* @bundles/IntegrationsBundle/Sync/Notification/Helper/UserSummaryNotificationHelper.php */
class __TwigTemplate_894e6bc9185fd7c32da6801acc0b9777 extends Template
{
    private Source $source;
    /**
     * @var array<string, Template>
     */
    private array $macros = [];

    public function __construct(Environment $env)
    {
        parent::__construct($env);

        $this->source = $this->getSourceContext();

        $this->parent = false;

        $this->blocks = [
        ];
    }

    protected function doDisplay(array $context, array $blocks = []): iterable
    {
        $macros = $this->macros;
        // line 1
        yield "<?php

declare(strict_types=1);

namespace Mautic\\IntegrationsBundle\\Sync\\Notification\\Helper;

use Mautic\\IntegrationsBundle\\Sync\\Exception\\ObjectNotSupportedException;
use Mautic\\IntegrationsBundle\\Sync\\Notification\\Writer;
use Symfony\\Contracts\\Translation\\TranslatorInterface;

class UserSummaryNotificationHelper
{
    /**
     * @var array
     */
    private \$userNotifications = [];

    /**
     * @var string
     */
    private \$integrationDisplayName;

    /**
     * @var string
     */
    private \$objectDisplayName;

    private ?string \$mauticObject = null;

    private ?string \$listTranslationKey = null;

    public function __construct(
        private Writer \$writer,
        private UserHelper \$userHelper,
        private OwnerProvider \$ownerProvider,
        private RouteHelper \$routeHelper,
        private TranslatorInterface \$translator
    ) {
    }

    /**
     * @throws ObjectNotSupportedException
     * @throws \\Doctrine\\ORM\\ORMException
     */
    public function writeNotifications(string \$mauticObject, string \$listTranslationKey): void
    {
        \$this->mauticObject       = \$mauticObject;
        \$this->listTranslationKey = \$listTranslationKey;

        if (empty(\$this->userNotifications)) {
            return;
        }

        foreach (\$this->userNotifications as \$integrationDisplayName => \$integrationNotifications) {
            foreach (\$integrationNotifications as \$objectDisplayName => \$objectNotifications) {
                \$this->integrationDisplayName = \$integrationDisplayName;
                \$this->objectDisplayName      = \$objectDisplayName;

                \$this->findAndSendToUsers(\$objectNotifications);
            }
        }

        \$this->userNotifications = [];
    }

    public function storeSummaryNotification(string \$integrationDisplayName, string \$objectDisplayName, int \$id): void
    {
        if (!isset(\$this->userNotifications[\$integrationDisplayName])) {
            \$this->userNotifications[\$integrationDisplayName] = [];
        }

        if (!isset(\$this->userNotifications[\$integrationDisplayName][\$objectDisplayName])) {
            \$this->userNotifications[\$integrationDisplayName][\$objectDisplayName] = [];
        }

        \$this->userNotifications[\$integrationDisplayName][\$objectDisplayName][\$id] = \$id;
    }

    /**
     * @throws \\Doctrine\\ORM\\ORMException
     * @throws ObjectNotSupportedException
     */
    private function findAndSendToUsers(array \$ids): void
    {
        \$results = \$this->ownerProvider->getOwnersForObjectIds(\$this->mauticObject, \$ids);
        \$owners  = [];

        // Group by owner ID.
        foreach (\$results as \$result) {
            \$ownerId = \$result['owner_id'];
            if (!isset(\$owners[\$ownerId])) {
                \$owners[\$ownerId] = [];
            }

            \$owners[\$ownerId][] = (int) \$result['id'];
        }

        foreach (\$owners as \$userId => \$ownedObjectIds) {
            // Keep track of who is left over to send to admins instead
            \$ids = array_diff(\$ids, \$ownedObjectIds);

            \$this->writeNotification(\$ownedObjectIds, \$userId);
        }

        if (count(\$ids)) {
            // Send the rest to admins
            \$adminUserIds = \$this->userHelper->getAdminUsers();
            foreach (\$adminUserIds as \$userId) {
                \$this->writeNotification(\$ids, \$userId);
            }
        }
    }

    /**
     * @throws ObjectNotSupportedException
     * @throws \\Doctrine\\ORM\\ORMException
     */
    private function writeNotification(array \$ids, int \$userId): void
    {
        \$count = count(\$ids);

        if (\$count > 25) {
            \$this->writer->writeUserNotification(
                \$this->translator->trans(
                    'mautic.integration.sync.user_notification.header',
                    [
                        '%integration%' => \$this->integrationDisplayName,
                        '%object%'      => ucfirst(\$this->objectDisplayName),
                    ]
                ),
                \$this->translator->trans(
                    'mautic.integration.sync.user_notification.count_message',
                    ['%count%' => \$count]
                ),
                \$userId
            );

            return;
        }

        \$this->writer->writeUserNotification(
            \$this->translator->trans(
                'mautic.integration.sync.user_notification.header',
                [
                    '%integration%' => \$this->integrationDisplayName,
                    '%object%'      => ucfirst(\$this->objectDisplayName),
                ]
            ),
            \$this->translator->trans(
                \$this->listTranslationKey,
                [
                    '%contacts%' => \$this->routeHelper->getLinkCsv(\$this->mauticObject, \$ids),
                ]
            ),
            \$userId
        );
    }
}
";
        yield from [];
    }

    /**
     * @codeCoverageIgnore
     */
    public function getTemplateName(): string
    {
        return "@bundles/IntegrationsBundle/Sync/Notification/Helper/UserSummaryNotificationHelper.php";
    }

    /**
     * @codeCoverageIgnore
     */
    public function getDebugInfo(): array
    {
        return array (  42 => 1,);
    }

    public function getSourceContext(): Source
    {
        return new Source("", "@bundles/IntegrationsBundle/Sync/Notification/Helper/UserSummaryNotificationHelper.php", "/var/www/html/mauticGIT-Test/app/bundles/IntegrationsBundle/Sync/Notification/Helper/UserSummaryNotificationHelper.php");
    }
}
